@@ -19,10 +19,10 @@
 #include "lexer.h"
 #include "lookup.h"
 
-#include <klocale.h>
+#include <KLocalizedString>
 
-#include <qregexp.h>
-#include <qmap.h>
+#include <QRegExp>
+#include <QMap>
 #include <QList>
 
 DEBUG_REGISTER_DISABLED(Lexer)
@@ -105,15 +105,15 @@ struct LexerData {
 };
 
 Lexer::Lexer(Driver* driver)
-    : d(new LexerData),
-      m_driver(driver),
-      m_recordComments(true),
-      m_recordWhiteSpaces(false),
-      m_skipWordsEnabled(true),
-      m_preprocessorEnabled(true),
-      m_inPreproc(false),
-      m_reportWarnings(false),
-      m_reportMessages(false)
+  : d(new LexerData),
+    m_driver(driver),
+    m_recordComments(true),
+    m_recordWhiteSpaces(false),
+    m_skipWordsEnabled(true),
+    m_preprocessorEnabled(true),
+    m_inPreproc(false),
+    m_reportWarnings(false),
+    m_reportMessages(false)
 {
     reset();
     d->beginScope();
@@ -830,7 +830,7 @@ int Lexer::macroPrimary()
 {
     readWhiteSpaces(false);
     int result = 0;
-    switch (currentChar().toAscii()) {
+    switch (currentChar().toLatin1()) {
     case '(':
         nextChar();
         result = macroExpression();
@@ -1026,9 +1026,3 @@ int Lexer::macroExpression()
     readWhiteSpaces(false);
     return macroLogicalOr();
 }
-
-// *IMPORTANT*
-// please, don't include lexer.moc here, because Lexer isn't a QObject class!!
-// if you have problem while recompiling try to remove cppsupport/.deps,
-// cppsupport/Makefile.in and rerun automake/autoconf
-
