@@ -222,10 +222,10 @@ void CodeGenerationPolicy::setLineEndingType (NewLineType type)
 {
     Settings::optionState().codeGenerationState.lineEndingType = type;
     switch (Settings::optionState().codeGenerationState.lineEndingType) {
-    case MAC:
+    case DOS:
         m_lineEndingChars = QString(QLatin1String("\r\n"));
         break;
-    case DOS:
+    case MAC:
         m_lineEndingChars = QString(QLatin1String("\r"));
         break;
     case UNIX:
@@ -462,8 +462,8 @@ void CodeGenerationPolicy::setDefaults(bool emitUpdateSignal)
     // settors below will each send the modifiedCodeContent() signal
     // needlessly (we can just make one call at the end).
 
-    setCodeVerboseSectionComments(UmbrelloSettings::forceDoc());
-    setCodeVerboseDocumentComments(UmbrelloSettings::forceSections());
+    setCodeVerboseSectionComments(UmbrelloSettings::forceSections());
+    setCodeVerboseDocumentComments(UmbrelloSettings::forceDoc());
     setLineEndingType(UmbrelloSettings::lineEndingType());
     setIndentationType(UmbrelloSettings::indentationType());
     setIndentationAmount(UmbrelloSettings::indentationAmount());
@@ -483,7 +483,7 @@ void CodeGenerationPolicy::setDefaults(bool emitUpdateSignal)
     if (path.isEmpty()) {
 #if QT_VERSION >= 0x050000
         path =  QStandardPaths::locateAll(QStandardPaths::GenericDataLocation,
-                                          QLatin1String("umbrello/headings"),
+                                          QLatin1String("umbrello5/headings"),
                                           QStandardPaths::LocateDirectory).first();
 #else
         KStandardDirs stddirs;
