@@ -121,6 +121,39 @@ bool CPPCodeGenerationPolicy::getDestructorsAreVirtual()
     return Settings::optionState().codeGenerationState.cppCodeGenerationState.virtualDestructors;
 }
 
+void CPPCodeGenerationPolicy::setGetterWithGetPrefix(bool var)
+{
+    Settings::optionState().codeGenerationState.cppCodeGenerationState.getterWithGetPrefix = var;
+    UMLApp::app()->commonPolicy()->emitModifiedCodeContentSig();
+}
+
+bool CPPCodeGenerationPolicy::getGetterWithGetPrefix()
+{
+    return Settings::optionState().codeGenerationState.cppCodeGenerationState.getterWithGetPrefix;
+}
+
+void CPPCodeGenerationPolicy::setRemovePrefixFromAccessorMethods(bool var)
+{
+    Settings::optionState().codeGenerationState.cppCodeGenerationState.removePrefixFromAccessorMethods = var;
+    UMLApp::app()->commonPolicy()->emitModifiedCodeContentSig();
+}
+
+bool CPPCodeGenerationPolicy::getRemovePrefixFromAccessorMethods()
+{
+    return Settings::optionState().codeGenerationState.cppCodeGenerationState.removePrefixFromAccessorMethods;
+}
+
+void CPPCodeGenerationPolicy::setAccessorMethodsStartWithUpperCase(bool var)
+{
+    Settings::optionState().codeGenerationState.cppCodeGenerationState.accessorMethodsStartWithUpperCase = var;
+    UMLApp::app()->commonPolicy()->emitModifiedCodeContentSig();
+}
+
+bool CPPCodeGenerationPolicy::getAccessorMethodsStartWithUpperCase()
+{
+    return Settings::optionState().codeGenerationState.cppCodeGenerationState.accessorMethodsStartWithUpperCase;
+}
+
 /**
  * Set the value of m_packageIsNamespace.
  * @param var the new value
@@ -203,6 +236,17 @@ void CPPCodeGenerationPolicy::setVectorClassNameInclude(const QString &value)
     UMLApp::app()->commonPolicy()->emitModifiedCodeContentSig();
 }
 
+void CPPCodeGenerationPolicy::setClassMemberPrefix(const QString &value)
+{
+    Settings::optionState().codeGenerationState.cppCodeGenerationState.classMemberPrefix = value;
+    UMLApp::app()->commonPolicy()->emitModifiedCodeContentSig();
+}
+
+QString CPPCodeGenerationPolicy::getClassMemberPrefix()
+{
+    return Settings::optionState().codeGenerationState.cppCodeGenerationState.classMemberPrefix;
+}
+
 void CPPCodeGenerationPolicy::setDocToolTag(const QString &value)
 {
     Settings::optionState().codeGenerationState.cppCodeGenerationState.docToolTag = value;
@@ -320,6 +364,9 @@ void CPPCodeGenerationPolicy::setDefaults(CPPCodeGenerationPolicy * cppclone, bo
         setAccessorsAreInline(cppclone->getAccessorsAreInline());
         setOperationsAreInline(cppclone->getOperationsAreInline());
         setDestructorsAreVirtual(cppclone->getDestructorsAreVirtual());
+        setGetterWithGetPrefix(cppclone->getGetterWithGetPrefix());
+        setRemovePrefixFromAccessorMethods(cppclone->getRemovePrefixFromAccessorMethods());
+        setAccessorMethodsStartWithUpperCase(cppclone->getAccessorMethodsStartWithUpperCase());
         setPackageIsNamespace(cppclone->getPackageIsNamespace());
 
         setStringClassName(cppclone->getStringClassName());
@@ -329,7 +376,9 @@ void CPPCodeGenerationPolicy::setDefaults(CPPCodeGenerationPolicy * cppclone, bo
         setVectorClassName(cppclone->getVectorClassName());
         setVectorClassNameInclude(cppclone->getVectorClassNameInclude());
         setVectorIncludeIsGlobal(cppclone->vectorIncludeIsGlobal());
+
         setDocToolTag(cppclone->getDocToolTag());
+        setClassMemberPrefix(cppclone->getClassMemberPrefix());
     }
 
     blockSignals(false); // "as you were citizen"
@@ -354,6 +403,9 @@ void CPPCodeGenerationPolicy::setDefaults(bool emitUpdateSignal)
     setAccessorsArePublic(UmbrelloSettings::publicAccessors());
     setOperationsAreInline(UmbrelloSettings::inlineOps());
     setDestructorsAreVirtual(UmbrelloSettings::virtualDestructors());
+    setGetterWithGetPrefix(UmbrelloSettings::getterWithGetPrefix());
+    setRemovePrefixFromAccessorMethods(UmbrelloSettings::removePrefixFromAccessorMethods());
+    setAccessorMethodsStartWithUpperCase(UmbrelloSettings::accessorMethodsStartWithUpperCase());
     setPackageIsNamespace(UmbrelloSettings::packageIsNamespace());
 
     setStringClassName(UmbrelloSettings::stringClassName());
@@ -363,7 +415,9 @@ void CPPCodeGenerationPolicy::setDefaults(bool emitUpdateSignal)
     setVectorClassName(UmbrelloSettings::vectorClassName());
     setVectorClassNameInclude(UmbrelloSettings::vectorClassNameInclude());
     setVectorIncludeIsGlobal(UmbrelloSettings::vectorIncludeIsGlobal());
+
     setDocToolTag(UmbrelloSettings::docToolTag());
+    setClassMemberPrefix(UmbrelloSettings::classMemberPrefix());
 
     blockSignals(false); // "as you were citizen"
 
@@ -401,6 +455,9 @@ void CPPCodeGenerationPolicy::init()
     setAccessorsArePublic(optionState.codeGenerationState.cppCodeGenerationState.publicAccessors);
     setOperationsAreInline(optionState.codeGenerationState.cppCodeGenerationState.inlineOps);
     setDestructorsAreVirtual(optionState.codeGenerationState.cppCodeGenerationState.virtualDestructors);
+    setGetterWithGetPrefix(optionState.codeGenerationState.cppCodeGenerationState.getterWithGetPrefix);
+    setRemovePrefixFromAccessorMethods(optionState.codeGenerationState.cppCodeGenerationState.removePrefixFromAccessorMethods);
+    setAccessorMethodsStartWithUpperCase(optionState.codeGenerationState.cppCodeGenerationState.accessorMethodsStartWithUpperCase);
     setPackageIsNamespace(optionState.codeGenerationState.cppCodeGenerationState.packageIsNamespace);
 
     setStringClassName(optionState.codeGenerationState.cppCodeGenerationState.stringClassName);
@@ -411,6 +468,9 @@ void CPPCodeGenerationPolicy::init()
     setVectorClassNameInclude(optionState.codeGenerationState.cppCodeGenerationState.vectorClassNameInclude);
     setVectorIncludeIsGlobal(optionState.codeGenerationState.cppCodeGenerationState.vectorIncludeIsGlobal);
 
+    setDocToolTag(optionState.codeGenerationState.cppCodeGenerationState.docToolTag);
+    setClassMemberPrefix(optionState.codeGenerationState.cppCodeGenerationState.classMemberPrefix);
+
     blockSignals(false);
 }
 
