@@ -71,7 +71,7 @@ QString DClassifierCodeDocument::getPath()
     QString path = getPackage();
 
     // Replace all white spaces with blanks
-    path.simplified();
+    path = path.simplified();
 
     // Replace all blanks with underscore
     path.replace(QRegExp(QLatin1String(" ")), QLatin1String("_"));
@@ -151,9 +151,9 @@ void DClassifierCodeDocument::loadChildTextBlocksFromNode(QDomElement & root)
 
                 if (name == QLatin1String("codecomment")) {
                     CodeComment * block = new DCodeComment(this);
-                    block->loadFromXMI(element);
+                    block->loadFromXMI1(element);
                     if (!addTextBlock(block)) {
-                        uError()<<"loadFromXMI : unable to add codeComment to :"<<this;
+                        uError()<<"loadFromXMI1 : unable to add codeComment to :"<<this;
                         delete block;
                     } else {
                         loadCheckForChildrenOK= true;
@@ -164,25 +164,25 @@ void DClassifierCodeDocument::loadChildTextBlocksFromNode(QDomElement & root)
                     // search for our method in the
                     TextBlock * tb = findCodeClassFieldTextBlockByTag(acctag);
                     if (!tb || !addTextBlock(tb)) {
-                        uError()<<"loadFromXMI : unable to add codeclassfield child method to:"<<this;
+                        uError()<<"loadFromXMI1 : unable to add codeclassfield child method to:"<<this;
                         // DON'T delete
                     } else {
                         loadCheckForChildrenOK= true;
                     }
                 } else if (name == QLatin1String("codeblock")) {
                     CodeBlock * block = newCodeBlock();
-                    block->loadFromXMI(element);
+                    block->loadFromXMI1(element);
                     if (!addTextBlock(block)) {
-                        uError()<<"loadFromXMI : unable to add codeBlock to :"<<this;
+                        uError()<<"loadFromXMI1 : unable to add codeBlock to :"<<this;
                         delete block;
                     } else {
                         loadCheckForChildrenOK= true;
                     }
                 } else if (name == QLatin1String("codeblockwithcomments")) {
                     CodeBlockWithComments * block = newCodeBlockWithComments();
-                    block->loadFromXMI(element);
+                    block->loadFromXMI1(element);
                     if (!addTextBlock(block)) {
-                        uError()<<"loadFromXMI : unable to add codeBlockwithcomments to:"<<this;
+                        uError()<<"loadFromXMI1 : unable to add codeBlockwithcomments to:"<<this;
                         delete block;
                     } else {
                         loadCheckForChildrenOK= true;
@@ -191,7 +191,7 @@ void DClassifierCodeDocument::loadChildTextBlocksFromNode(QDomElement & root)
                     // do nothing.. this is treated elsewhere
                 } else if (name == QLatin1String("hierarchicalcodeblock")) {
                     HierarchicalCodeBlock * block = newHierarchicalCodeBlock();
-                    block->loadFromXMI(element);
+                    block->loadFromXMI1(element);
                     if (!addTextBlock(block)) {
                         uError()<<"Unable to add hierarchicalcodeBlock to:"<<this;
                         delete block;
@@ -202,10 +202,10 @@ void DClassifierCodeDocument::loadChildTextBlocksFromNode(QDomElement & root)
                     // find the code operation by id
                     QString id = element.attribute(QLatin1String("parent_id"), QLatin1String("-1"));
                     UMLObject * obj = UMLApp::app()->document()->findObjectById(Uml::ID::fromString(id));
-                    UMLOperation * op = dynamic_cast<UMLOperation*>(obj);
+                    UMLOperation * op = obj->asUMLOperation();
                     if (op) {
                         CodeOperation * block = new DCodeOperation(this, op);
-                        block->loadFromXMI(element);
+                        block->loadFromXMI1(element);
                         if (addTextBlock(block)) {
                             loadCheckForChildrenOK= true;
                         } else {
@@ -217,7 +217,7 @@ void DClassifierCodeDocument::loadChildTextBlocksFromNode(QDomElement & root)
                     }
                 } else if (name == QLatin1String("dclassdeclarationblock")) {
                     DClassDeclarationBlock * block = getClassDecl();
-                    block->loadFromXMI(element);
+                    block->loadFromXMI1(element);
                     if (!addTextBlock(block)) {
                         uError()<<"Unable to add d code declaration block to:"<<this;
                         // DON'T delete.
@@ -280,7 +280,7 @@ void DClassifierCodeDocument::updateContent()
 {
     // Gather info on the various fields and parent objects of this class...
     UMLClassifier * c = getParentClassifier();
-    Q_ASSERT(c != NULL);
+    Q_ASSERT(c != 0);
     CodeGenerationPolicy * commonPolicy = UMLApp::app()->commonPolicy();
     CodeGenPolicyExt * pe = UMLApp::app()->policyExt();
     DCodeGenerationPolicy * policy = dynamic_cast<DCodeGenerationPolicy*>(pe);
@@ -351,7 +351,7 @@ void DClassifierCodeDocument::updateContent()
         // NO (default) datatypes in the import statement.. use defined
         // ones whould be possible, but no idea how to do that...at least for now.
         // Dynamic casting is slow..not an optimal way to do this.
-        if (!packageMap.contains(con) && con->baseType() != UMLObject::ot_Datatype)
+        if (!packageMap.contains(con) && !con->isUMLDatatype())
         {
             packageMap.insert(con, con->package());
 
@@ -534,4 +534,3 @@ void DClassifierCodeDocument::updateContent()
 
 }
 
-#include "dclassifiercodedocument.moc"
