@@ -25,7 +25,7 @@ public:
     /**
      * Empty Constructor
      */
-    explicit JavaClassDeclarationBlock (JavaClassifierCodeDocument * parentDoc, const QString &start = "", const QString &endText = "}", const QString &comment = "");
+    explicit JavaClassDeclarationBlock (JavaClassifierCodeDocument * parentDoc, const QString &start = QString(), const QString &endText = QLatin1String("}"), const QString &comment = QString());
 
     /**
      * Empty Destructor
@@ -35,12 +35,12 @@ public:
     /**
      * Save the XMI representation of this object
      */
-    virtual void saveToXMI (QDomDocument & doc, QDomElement & root);
+    virtual void saveToXMI1 (QDomDocument & doc, QDomElement & root);
 
     /**
      * load params from the appropriate XMI element node.
      */
-    virtual void loadFromXMI (QDomElement & root);
+    virtual void loadFromXMI1 (QDomElement & root);
 
     /**
      * Update the start/end text of this codeblock.
