@@ -82,9 +82,7 @@ QString JavaClassifierCodeDocument::getPath ()
     path.replace(QRegExp(QLatin1String("\\.")),QLatin1String("/"));
     path.replace(QRegExp(QLatin1String("::")), QLatin1String("/"));
 
-    path.toLower();
-
-    return path;
+    return path.toLower();
 }
 
 QString JavaClassifierCodeDocument::getJavaClassName (const QString &name)
@@ -117,9 +115,9 @@ void JavaClassifierCodeDocument::init ()
 bool JavaClassifierCodeDocument::addCodeOperation (CodeOperation * op)
 {
     if (!op->getParentOperation()->isLifeOperation())
-        return operationsBlock == NULL ? false : operationsBlock->addTextBlock(op);
+        return operationsBlock == 0 ? false : operationsBlock->addTextBlock(op);
     else
-        return constructorBlock == NULL ? false : constructorBlock->addTextBlock(op);
+        return constructorBlock == 0 ? false : constructorBlock->addTextBlock(op);
 }
 
 // Sigh. NOT optimal. The only reason that we need to have this
@@ -148,9 +146,9 @@ void JavaClassifierCodeDocument::loadChildTextBlocksFromNode (QDomElement & root
 
                 if (name == QLatin1String("codecomment")) {
                     CodeComment * block = new JavaCodeComment(this);
-                    block->loadFromXMI(element);
+                    block->loadFromXMI1(element);
                     if (!addTextBlock(block)) {
-                        uError()<<"loadFromXMI : unable to add codeComment to :"<<this;
+                        uError()<<"loadFromXMI1 : unable to add codeComment to :"<<this;
                         delete block;
                     } else {
                         loadCheckForChildrenOK= true;
@@ -161,25 +159,25 @@ void JavaClassifierCodeDocument::loadChildTextBlocksFromNode (QDomElement & root
                     // search for our method in the
                     TextBlock * tb = findCodeClassFieldTextBlockByTag(acctag);
                     if (!tb || !addTextBlock(tb)) {
-                        uError()<<"loadFromXMI : unable to add codeclassfield child method to:"<<this;
+                        uError()<<"loadFromXMI1 : unable to add codeclassfield child method to:"<<this;
                         // DON'T delete
                     } else {
                         loadCheckForChildrenOK= true;
                     }
                 } else if (name == QLatin1String("codeblock")) {
                     CodeBlock * block = newCodeBlock();
-                    block->loadFromXMI(element);
+                    block->loadFromXMI1(element);
                     if (!addTextBlock(block)) {
-                        uError()<<"loadFromXMI : unable to add codeBlock to :"<<this;
+                        uError()<<"loadFromXMI1 : unable to add codeBlock to :"<<this;
                         delete block;
                     } else {
                         loadCheckForChildrenOK= true;
                     }
                 } else if (name == QLatin1String("codeblockwithcomments")) {
                     CodeBlockWithComments * block = newCodeBlockWithComments();
-                    block->loadFromXMI(element);
+                    block->loadFromXMI1(element);
                     if (!addTextBlock(block)) {
-                        uError()<<"loadFromXMI : unable to add codeBlockwithcomments to:"<<this;
+                        uError()<<"loadFromXMI1 : unable to add codeBlockwithcomments to:"<<this;
                         delete block;
                     } else {
                         loadCheckForChildrenOK= true;
@@ -188,7 +186,7 @@ void JavaClassifierCodeDocument::loadChildTextBlocksFromNode (QDomElement & root
                     // do nothing.. this is treated elsewhere
                 } else if (name == QLatin1String("hierarchicalcodeblock")) {
                     HierarchicalCodeBlock * block = newHierarchicalCodeBlock();
-                    block->loadFromXMI(element);
+                    block->loadFromXMI1(element);
                     if (!addTextBlock(block)) {
                         uError()<<"Unable to add hierarchicalcodeBlock to:"<<this;
                         delete block;
@@ -199,10 +197,10 @@ void JavaClassifierCodeDocument::loadChildTextBlocksFromNode (QDomElement & root
                     // find the code operation by id
                     QString id = element.attribute(QLatin1String("parent_id"), QLatin1String("-1"));
                     UMLObject * obj = UMLApp::app()->document()->findObjectById(Uml::ID::fromString(id));
-                    UMLOperation * op = dynamic_cast<UMLOperation*>(obj);
+                    UMLOperation * op = obj->asUMLOperation();
                     if (op) {
                         CodeOperation * block = new JavaCodeOperation(this, op);
-                        block->loadFromXMI(element);
+                        block->loadFromXMI1(element);
                         if (addTextBlock(block)) {
                             loadCheckForChildrenOK= true;
                         } else {
@@ -214,7 +212,7 @@ void JavaClassifierCodeDocument::loadChildTextBlocksFromNode (QDomElement & root
                     }
                 } else if (name == QLatin1String("javaclassdeclarationblock")) {
                     JavaClassDeclarationBlock * block = getClassDecl();
-                    block->loadFromXMI(element);
+                    block->loadFromXMI1(element);
                     if (!addTextBlock(block)) {
                         uError()<<"Unable to add java code declaration block to:"<<this;
                         // DON'T delete.
@@ -273,7 +271,7 @@ void JavaClassifierCodeDocument::updateContent()
 {
     // Gather info on the various fields and parent objects of this class...
     UMLClassifier * c = getParentClassifier();
-    Q_ASSERT(c != NULL);
+    Q_ASSERT(c != 0);
     CodeGenerationPolicy * commonPolicy = UMLApp::app()->commonPolicy();
     CodeGenPolicyExt * pe = UMLApp::app()->policyExt();
     JavaCodeGenerationPolicy * policy = dynamic_cast<JavaCodeGenerationPolicy*>(pe);
@@ -344,7 +342,7 @@ void JavaClassifierCodeDocument::updateContent()
         // NO (default) datatypes in the import statement.. use defined
         // ones whould be possible, but no idea how to do that...at least for now.
         // Dynamic casting is slow..not an optimal way to do this.
-        if (!packageMap.contains(con) && con->baseType() != UMLObject::ot_Datatype)
+        if (!packageMap.contains(con) && !con->isUMLDatatype())
         {
             packageMap.insert(con, con->package());
 
