@@ -31,7 +31,7 @@ public:
     /**
      * Constructors
      */
-    explicit JavaCodeDocumentation (JavaClassifierCodeDocument * doc, const QString & text = "");
+    explicit JavaCodeDocumentation (JavaClassifierCodeDocument * doc, const QString & text = QString());
 
     /**
      * Empty Destructor
@@ -41,7 +41,7 @@ public:
     /**
      * Save the XMI representation of this object
      */
-    virtual void saveToXMI (QDomDocument & doc, QDomElement & root);
+    virtual void saveToXMI1 (QDomDocument & doc, QDomElement & root);
 
     /**
      * @return  QString
@@ -52,7 +52,7 @@ public:
     * UnFormat a long text string. Typically, this means removing
     * the indentaion (linePrefix) and/or newline chars from each line.
     */
-    virtual QString unformatText (const QString & text, const QString & indent = "");
+    virtual QString unformatText (const QString & text, const QString & indent = QString());
 
     /**
      * A special version here because we want to not only indent
