@@ -32,7 +32,7 @@ public:
      * Constructor with QString so we can create & populate it in
      * one step.
      */
-    OwnedHierarchicalCodeBlock (UMLObject * parent, CodeDocument * parentDoc, const QString &start="", const QString &end="", const QString &comment="");
+    OwnedHierarchicalCodeBlock (UMLObject * parent, CodeDocument * parentDoc, const QString &start = QString(), const QString &end = QString(), const QString &comment = QString());
 
     /**
      * Empty Destructor
@@ -48,12 +48,12 @@ public:
     /**
      * Save the XMI representation of this object
      */
-    virtual void saveToXMI (QDomDocument & doc, QDomElement & root) = 0;
+    virtual void saveToXMI1 (QDomDocument & doc, QDomElement & root) = 0;
 
     /**
      * load params from the appropriate XMI element node.
      */
-    virtual void loadFromXMI (QDomElement & root) = 0;
+    virtual void loadFromXMI1 (QDomElement & root) = 0;
 
 protected:
 
