@@ -415,7 +415,7 @@ bool CSharpImport::parseStmt()
         }
         Import_Utils::insertMethod(m_klass, op, m_currentAccess, typeName,
                                    m_isStatic, m_isAbstract, false /*isFriend*/,
-                                   false /*isConstructor*/, m_comment);
+                                   false /*isConstructor*/, false, m_comment);
         m_isAbstract = m_isStatic = false;
         // reset the default visibility
         m_currentAccess = m_defaultCurrentAccess;
@@ -637,7 +637,8 @@ bool CSharpImport::parseEnumDeclaration()
                 Import_Utils::addEnumLiteral(enumType, m_source[m_srcIndex - 2], QString(), m_source[m_srcIndex]);
             next = advance();
         } else {
-            Import_Utils::addEnumLiteral(enumType, m_source[m_srcIndex - 1]);
+            if (enumType != 0)
+                Import_Utils::addEnumLiteral(enumType, m_source[m_srcIndex - 1]);
         }
         if (next == QLatin1String("{") || next == QLatin1String("(")) {
             if (! skipToClosing(next[0]))
