@@ -362,6 +362,48 @@ UMLObject *createUMLObject(UMLObject::ObjectType type,
     return o;
 }
 
+/**
+ * Create hierachical tree of UML objects
+ *
+ * This methods creates the UML object specified by #type and #name including an optional namespace hierachy
+ * if included in the #name e.g. NamespaceA::ClassA in C++.
+ *
+ * @param type  type of UML object to create
+ * @param name  name of UML object
+ * @param topLevelParent  UML package to add the hierachie of UML objects
+ * @return pointer to created or found UML object
+ */
+UMLObject* createUMLObjectHierachy(UMLObject::ObjectType type, const QString &name, UMLPackage *topLevelParent)
+{
+    UMLPackage *parent = topLevelParent;
+    QString objectName;
+    QString scopeSeparator = UMLApp::app()->activeLanguageScopeSeparator();
+    UMLObject *o = nullptr;
+    if (name.contains(scopeSeparator)) {
+        QStringList components =  name.split(scopeSeparator);
+        objectName = components.takeLast();
+        foreach(const QString scopeName, components) {
+            o = parent->findObject(scopeName);
+            if (o && (o->isUMLPackage() || o->isUMLClassifier())) {
+                parent = o->asUMLPackage();
+                continue;
+            }
+            o = Object_Factory::createNewUMLObject(UMLObject::ot_Class, scopeName, parent, false);
+            parent->addObject(o);
+            o->setStereotypeCmd(QLatin1String("class-or-package"));
+            parent = o->asUMLPackage();
+        }
+    } else {
+        objectName = name;
+    }
+    o = parent->findObject(objectName);
+    if (o && (o->isUMLPackage() || o->isUMLClassifier()))
+        return o;
+    o = Object_Factory::createNewUMLObject(type, objectName, parent);
+    parent->addObject(o);
+    return o;
+}
+
 /**
  * Create a UMLOperation.
  * The reason for this method is to not generate any Qt signals.
@@ -657,7 +699,31 @@ UMLObject *createArtifact(const QString& name,
  */
 void createGeneralization(UMLClassifier *child, const QString &parentName)
 {
-    UMLObject *parentObj = createUMLObject(UMLObject::ot_Class, parentName);
+    const QString& scopeSep = UMLApp::app()->activeLanguageScopeSeparator();
+    UMLObject *parentObj = 0;
+    if (parentName.contains(scopeSep)) {
+        QStringList split = parentName.split(scopeSep);
+        QString className = split.last();
+        split.pop_back(); // remove the classname
+        UMLPackage *parent = 0;
+        UMLPackage *current = 0;
+        for (QStringList::Iterator it = split.begin(); it != split.end(); ++it) {
+            QString name = (*it);
+            UMLObject *ns = Import_Utils::createUMLObject(UMLObject::ot_Package,
+                                                          name, parent,
+                                                          QString(), QString(),
+                                                          true, false);
+            current = ns->asUMLPackage();
+            parent = current;
+        }
+        UMLObject::ObjectType type = UMLObject::ot_Class;
+        if (child->baseType() == UMLObject::ot_Interface)
+          type = UMLObject::ot_Interface;
+        parentObj = Import_Utils::createUMLObject(type, className, parent,
+                                                  QString(), QString(), true, false);
+    } else {
+        parentObj = createUMLObject(UMLObject::ot_Class, parentName);
+    }
     UMLClassifier *parent = parentObj->asUMLClassifier();
     createGeneralization(child, parent);
 }
@@ -731,4 +797,13 @@ bool isDatatype(const QString& name, UMLPackage *parentPkg)
     return (o != 0);
 }
 
+/**
+ * Returns the UML package of the global scope.
+ */
+UMLPackage *globalScope()
+{
+    UMLFolder *logicalView = UMLApp::app()->document()->rootFolder(Uml::ModelType::Logical);
+    return logicalView;
+}
+
 }  // end namespace Import_Utils
