@@ -17,7 +17,7 @@
 #include "import_utils.h"
 
 // kde includes
-#include <klocale.h>
+#include <KLocalizedString>
 
 // qt includes
 #include <QFile>
@@ -178,6 +178,17 @@ int NativeImportBase::scopeIndex()
     return m_scope.size() - 1;
 }
 
+/**
+ * Get the next lexeme without advancing.
+ * @return  the next lexeme or an empty string
+ */
+QString NativeImportBase::lookAhead()
+{
+    if (m_srcIndex < m_source.count() - 1)
+        return m_source[m_srcIndex+1];
+    return QString();
+}
+
 /**
  * Advance m_srcIndex until m_source[m_srcIndex] contains a non-comment.
  * Comments encountered during advancement are accumulated in `m_comment'.
@@ -464,10 +475,10 @@ bool NativeImportBase::parseFile(const QString& filename)
                          QLatin1String(" / lines: ") + QString::number(lineCount));
     file.close();
     // Parse the QStringList m_source.
-    m_klass = NULL;
+    m_klass = 0;
     m_currentAccess = Uml::Visibility::Public;
     m_scope.clear();
-    pushScope(0); // index 0 is reserverd for the global scope
+    pushScope(Import_Utils::globalScope()); // index 0 is reserverd for the global scope
     const int srcLength = m_source.count();
     for (m_srcIndex = 0; m_srcIndex < srcLength; ++m_srcIndex) {
         const QString& firstToken = m_source[m_srcIndex];
