@@ -15,16 +15,16 @@
 
 #include "codeviewerstate.h"
 #include "ui_codeviewerdialogbase.h"
+#include "singlepagedialogbase.h"
 
 class CodeDocument;
 
-
 /**
  * This class is sooo ugly I don't know where to begin. For now, its a prototype
  * that works, and thats all we need. In the future, a re-write is mandated to
  * bring a bit of beauty to this beast. -b.t.
  */
-class CodeViewerDialog : public KDialog, private Ui::CodeViewerDialogBase
+class CodeViewerDialog : public SinglePageDialogBase, private Ui::CodeViewerDialogBase
 {
     Q_OBJECT
 public:
