@@ -10,12 +10,18 @@
 #ifndef EXPORTALLVIEWSDIALOG_H
 #define EXPORTALLVIEWSDIALOG_H
 
-// application specific includes
+// app includes
 #include "ui_exportallviewsdialogbase.h"
+#include "imagetypewidget.h"
+#include "resolutionwidget.h"
 #include "singlepagedialogbase.h"
 
 // KDE forward declarations
+#if QT_VERSION >= 0x050000
+class KComboBox;
+#else
 class KFileFilterCombo;
+#endif
 
 /**
  * Dialog for collecting the "Export all views" params.
@@ -36,15 +42,15 @@ public:
     ~ExportAllViewsDialog();
 
 private:
-
-    KFileFilterCombo* m_imageType;  ///< The image type selected.
+    ImageTypeWidget* m_imageType;  ///< The image type selected.
+    ResolutionWidget* m_imageResolution;  ///< The image resolution selected.
 
 protected slots:
 
     friend class UMLViewImageExporterAll;
 
     virtual void languageChange();
-
+    void slotImageTypeChanged(QString imageType);
 };
 
 #endif
