@@ -27,9 +27,15 @@ class KFontChooser;
 class KPageDialog;
 class QAbstractButton;
 class QFrame;
+class NotePage;
+class NoteWidget;
+class MessageWidget;
 class UMLWidget;
+class SelectOperationPage;
 class UMLWidgetStylePage;
 class WidgetBase;
+class UMLScene;
+namespace Settings { class OptionState; }
 
 /**
  * Base class for property dialogs
@@ -80,16 +86,21 @@ signals:
     void applyClicked();
     void defaultClicked();
 
+protected slots:
+    void slotEnableButtonOk(bool state);
+
 private slots:
     void slotOkClicked();
     void slotApplyClicked();
     void slotDefaultClicked();
-    void slotHelpClicked();
 #if QT_VERSION >= 0x050000
+    void slotHelpClicked();
     void slotButtonClicked(QAbstractButton *button);
 #endif
 protected:
     AssociationGeneralPage *m_pAssocGeneralPage;
+    NotePage *m_notePage;
+    SelectOperationPage *m_operationGeneralPage;
     AssociationRolePage *m_pRolePage;
     KFontChooser *m_fontChooser;
     UMLWidgetStylePage *m_pStylePage;
@@ -106,11 +117,18 @@ protected:
     void setupGeneralPage(AssociationWidget *widget);
     void applyGeneralPage(AssociationWidget *widget);
 
+    void setupGeneralPage(NoteWidget *widget);
+    KPageWidgetItem *setupGeneralPage(MessageWidget *widget);
+    void applyGeneralPage(MessageWidget *widget);
+
     KPageWidgetItem *setupFontPage(const QFont &font);
     KPageWidgetItem *setupFontPage(UMLWidget *widget);
     KPageWidgetItem *setupFontPage(AssociationWidget *widget);
-    void applyFontPage(UMLWidget *widget);
+    void resetFontPage(QWidget *widget);
     void applyFontPage(AssociationWidget *widget);
+    void applyFontPage(Settings::OptionState *state);
+    void applyFontPage(UMLScene *scene);
+    void applyFontPage(UMLWidget *wigdet);
 
     KPageWidgetItem *setupStylePage(WidgetBase *widget);
     KPageWidgetItem *setupStylePage(AssociationWidget *widget);
