@@ -22,8 +22,8 @@
 // kde includes
 #include <kcombobox.h>
 #include <klineedit.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <KLocalizedString>
+#include <KMessageBox>
 #include <ktextedit.h>
 
 // qt includes
@@ -36,7 +36,6 @@
 
 /**
  *  Sets up the AssociationRolePage.
- *  @param  d       The UMLDoc which controls controls object creation.
  *  @param  parent  The parent to the AssociationRolePage.
  *  @param  assoc   The AssociationWidget to display the properties of.
  */
@@ -110,13 +109,13 @@ void AssociationRolePage::constructWidget()
     //
 
     // Rolename A
-    QLabel *pRoleAL = NULL;
+    QLabel *pRoleAL = 0;
     Dialog_Utils::makeLabeledEditField(propsALayout, 0,
                                     pRoleAL, i18n("Rolename:"),
                                     m_pRoleALE, nameA);
 
     // Multi A
-    QLabel *pMultiAL = NULL;
+    QLabel *pMultiAL = 0;
     pMultiAL = new QLabel(i18n("Multiplicity:"), propsAGB);
     m_pMultiACB = new KComboBox(propsAGB);
     m_pMultiACB->addItems(multiplicities);
@@ -159,13 +158,13 @@ void AssociationRolePage::constructWidget()
     }
 
     // Rolename B
-    QLabel * pRoleBL = NULL;
+    QLabel * pRoleBL = 0;
     Dialog_Utils::makeLabeledEditField(propsBLayout, 0,
                                     pRoleBL, i18n("Rolename:"),
                                     m_pRoleBLE, nameB);
 
     // Multi B
-    QLabel *pMultiBL = NULL;
+    QLabel *pMultiBL = 0;
     pMultiBL = new QLabel(i18n("Multiplicity:"), propsBGB);
     m_pMultiBCB = new KComboBox(propsBGB);
     m_pMultiBCB->addItems(multiplicities);
@@ -275,4 +274,3 @@ void AssociationRolePage::apply()
     } //end if m_pAssociationWidget
 }
 
-#include "associationrolepage.moc"
