@@ -18,8 +18,9 @@
 #include "operation.h"
 #include "classifier.h"
 #include "template.h"
-#include "listpopupmenu.h"
+#include "dialogspopupmenu.h"
 #include "umlattributelist.h"
+#include "umldatatypewidget.h"
 #include "umlstereotypewidget.h"
 #include "classifierlistitem.h"
 #include "documentationwidget.h"
@@ -31,11 +32,13 @@
 #include "visibilityenumwidget.h"
 
 //kde includes
+#if QT_VERSION < 0x050000
+#include <kdialogbuttonbox.h>
+#endif
 #include <klineedit.h>
 #include <kcombobox.h>
-#include <klocale.h>
-#include <kmessagebox.h>
-#include <kdialogbuttonbox.h>
+#include <KLocalizedString>
+#include <KMessageBox>
 
 //qt includes
 #include <QCheckBox>
@@ -55,7 +58,8 @@
  * Constructor.
  */
 UMLOperationDialog::UMLOperationDialog(QWidget * parent, UMLOperation * pOperation)
-  : SinglePageDialogBase(parent)
+  : SinglePageDialogBase(parent),
+    m_pOverrideCB(0)
 {
     setCaption(i18n("Operation Properties"));
     m_operation = pOperation;
@@ -94,18 +98,16 @@ void UMLOperationDialog::setupDialog()
                                     m_pNameL, i18nc("operation name", "&Name:"),
                                     m_pNameLE, m_operation->name());
 
-    m_pRtypeL = new QLabel(i18n("&Type:"), m_pGenGB);
-    genLayout->addWidget(m_pRtypeL, 0, 2);
-
-    m_pRtypeCB = new KComboBox(true, m_pGenGB);
-    genLayout->addWidget(m_pRtypeCB, 0, 3);
-    m_pRtypeL->setBuddy(m_pRtypeCB);
+    m_datatypeWidget = new UMLDatatypeWidget(m_operation);
+    m_datatypeWidget->addToLayout(genLayout, 0, 2);
 
     m_stereotypeWidget = new UMLStereotypeWidget(m_operation);
     m_stereotypeWidget->addToLayout(genLayout, 1);
 
+    bool isInterface = m_operation->umlPackage()->asUMLClassifier()->isInterface();
     m_pAbstractCB = new QCheckBox(i18n("&Abstract operation"), m_pGenGB);
     m_pAbstractCB->setChecked(m_operation->isAbstract());
+    m_pAbstractCB->setEnabled(!isInterface);
     genLayout->addWidget(m_pAbstractCB, 2, 0);
     m_pStaticCB = new QCheckBox(i18n("Classifier &scope (\"static\")"), m_pGenGB);
     m_pStaticCB->setChecked(m_operation->isStatic());
@@ -113,8 +115,23 @@ void UMLOperationDialog::setupDialog()
     m_pQueryCB = new QCheckBox(i18n("&Query (\"const\")"), m_pGenGB);
     m_pQueryCB->setChecked(m_operation->getConst());
     genLayout->addWidget(m_pQueryCB, 2, 2);
+    m_virtualCB = new QCheckBox(i18n("&virtual"), m_pGenGB);
+    m_virtualCB->setChecked(m_operation->isVirtual());
+    m_virtualCB->setEnabled(!isInterface);
+    genLayout->addWidget(m_virtualCB, 2, 3);
+    m_inlineCB = new QCheckBox(i18n("&inline"), m_pGenGB);
+    m_inlineCB->setChecked(m_operation->isInline());
+    m_inlineCB->setEnabled(!isInterface);
+    genLayout->addWidget(m_inlineCB, 2, 4);
+    if (Settings::optionState().codeImportState.supportCPP11) {
+        m_pOverrideCB = new QCheckBox(i18n("&Override"), m_pGenGB);
+        m_pOverrideCB->setChecked(m_operation->getOverride());
+        m_pOverrideCB->setEnabled(!isInterface);
+        genLayout->addWidget(m_pOverrideCB, 2, 5);
+    }
 
     m_visibilityEnumWidget = new VisibilityEnumWidget(m_operation, this);
+    m_visibilityEnumWidget->setEnabled(!isInterface);
 
     m_docWidget = new DocumentationWidget(m_operation, this);
 
@@ -141,6 +158,15 @@ void UMLOperationDialog::setupDialog()
     m_pDownButton->setEnabled(false);
     buttonLayout->addWidget(m_pDownButton);
 
+#if QT_VERSION >= 0x050000
+    QDialogButtonBox* buttonBox = new QDialogButtonBox(m_pParmsGB);
+    QPushButton* newParam = buttonBox->addButton(i18n("Ne&w Parameter..."), QDialogButtonBox::ActionRole);
+    connect(newParam, SIGNAL(clicked()), this, SLOT(slotNewParameter()));
+    m_pDeleteButton = buttonBox->addButton(i18n("&Delete"), QDialogButtonBox::ActionRole);
+    connect(m_pDeleteButton, SIGNAL(clicked()), this, SLOT(slotDeleteParameter()));
+    m_pPropertiesButton = buttonBox->addButton(i18n("&Properties"), QDialogButtonBox::ActionRole);
+    connect(m_pPropertiesButton, SIGNAL(clicked()), this, SLOT(slotParameterProperties()));
+#else
     KDialogButtonBox* buttonBox = new KDialogButtonBox(m_pParmsGB);
     buttonBox->addButton(i18n("Ne&w Parameter..."), KDialogButtonBox::ActionRole,
                           this, SLOT(slotNewParameter()));
@@ -148,6 +174,7 @@ void UMLOperationDialog::setupDialog()
                                             this, SLOT(slotDeleteParameter()));
     m_pPropertiesButton = buttonBox->addButton(i18n("&Properties"), KDialogButtonBox::ActionRole,
                           this, SLOT(slotParameterProperties()));
+#endif
 
     parmsHBoxLayout->addWidget(m_pParmsLW);
     parmsHBoxLayout->addLayout(buttonLayout);
@@ -165,11 +192,6 @@ void UMLOperationDialog::setupDialog()
     m_pUpButton->setEnabled(false);
     m_pDownButton->setEnabled(false);
 
-    m_pRtypeCB->setDuplicatesEnabled(false); // only allow one of each type in box
-    m_pRtypeCB->setCompletionMode(KGlobalSettings::CompletionPopup);
-    // add the return types
-    insertTypesSorted(m_operation->getTypeName());
-
     // fill in parm list box
     UMLAttributeList list = m_operation->getParmList();
     foreach (UMLAttribute* pAtt, list) {
@@ -199,14 +221,14 @@ void UMLOperationDialog::slotNameChanged(const QString &_text)
 
 void UMLOperationDialog::slotParmRightButtonPressed(const QPoint &p)
 {
-    ListPopupMenu::MenuType type = ListPopupMenu::mt_Undefined;
+    DialogsPopupMenu::TriggerType type = DialogsPopupMenu::tt_Undefined;
     QListWidgetItem* item = m_pParmsLW->itemAt(p);
     if (item) // pressed on an item
     {
-        type = ListPopupMenu::mt_Parameter_Selected;
+        type = DialogsPopupMenu::tt_Parameter_Selected;
     } else // pressed into fresh air
     {
-        type = ListPopupMenu::mt_New_Parameter;
+        type = DialogsPopupMenu::tt_New_Parameter;
     }
     if (m_menu) {
         m_menu->hide();
@@ -214,7 +236,7 @@ void UMLOperationDialog::slotParmRightButtonPressed(const QPoint &p)
         delete m_menu;
         m_menu = 0;
     }
-    ListPopupMenu popup(this, type);
+    DialogsPopupMenu popup(this, type);
     QAction *triggered = popup.exec(m_pParmsLW->mapToGlobal(p));
     slotMenuSelection(triggered);
 }
@@ -225,20 +247,20 @@ void UMLOperationDialog::slotParmDoubleClick(QListWidgetItem *item)
         return;
     }
     // this happens, when there was no right click in the list widget
-    ListPopupMenu popup(this, ListPopupMenu::mt_Parameter_Selected);
-    QAction* action = popup.getAction(ListPopupMenu::mt_Properties);
-    slotMenuSelection(action);
+    DialogsPopupMenu popup(this, DialogsPopupMenu::tt_Parameter_Selected);
+    QAction *triggered = popup.getAction(DialogsPopupMenu::mt_Properties);
+    slotMenuSelection(triggered);
 }
 
 void UMLOperationDialog::slotMenuSelection(QAction* action)
 {
-    ListPopupMenu::MenuType id = ListPopupMenu::typeFromAction(action);
-    if(id == ListPopupMenu::mt_Rename || id == ListPopupMenu::mt_Properties) {
+    DialogsPopupMenu::MenuType id = DialogsPopupMenu::typeFromAction(action);
+    if(id == DialogsPopupMenu::mt_Rename || id == DialogsPopupMenu::mt_Properties) {
         slotParameterProperties();
-    } else if(id == ListPopupMenu::mt_New_Parameter) {
+    } else if(id == DialogsPopupMenu::mt_New_Parameter) {
         slotNewParameter();
     }
-    else if(id == ListPopupMenu::mt_Delete) {
+    else if(id == DialogsPopupMenu::mt_Delete) {
         slotDeleteParameter();
     }
 }
@@ -296,7 +318,7 @@ void UMLOperationDialog::slotParameterProperties()
     } // should never occur
 
     QString oldAttName = pOldAtt->name();
-    UMLAttribute* tempAttribute = static_cast<UMLAttribute*>(pOldAtt->clone()); // create a clone of the parameter
+    UMLAttribute* tempAttribute = pOldAtt->clone()->asUMLAttribute(); // create a clone of the parameter
 
     // send the clone to the properties dialog box. it will fill in the new parameters.
     QPointer<ParameterPropertiesDialog> dlg = new ParameterPropertiesDialog(this, m_doc, tempAttribute);
@@ -397,7 +419,7 @@ bool UMLOperationDialog::apply()
         return false;
     }
 
-    UMLClassifier *classifier = dynamic_cast<UMLClassifier*>(m_operation->parent());
+    UMLClassifier *classifier = m_operation->umlParent()->asUMLClassifier();
     if(classifier != 0 &&
             classifier->checkOperationSignature(name, m_operation->getParmList(), m_operation))
     {
@@ -410,17 +432,7 @@ bool UMLOperationDialog::apply()
     m_operation->setName(name);
 
     m_visibilityEnumWidget->apply();
-
-    QString typeName = m_pRtypeCB->currentText();
-    UMLTemplate *tmplParam = 0;
-    if (classifier) {
-        tmplParam = classifier->findTemplate(typeName);
-    }
-    if (tmplParam)
-        m_operation->setType(tmplParam);
-    else
-        m_operation->setTypeName(typeName);
-
+    m_datatypeWidget->apply();
     m_stereotypeWidget->apply();
 
     bool isAbstract = m_pAbstractCB->isChecked();
@@ -437,53 +449,13 @@ bool UMLOperationDialog::apply()
     }
     m_operation->setStatic(m_pStaticCB->isChecked());
     m_operation->setConst(m_pQueryCB->isChecked());
+    m_operation->setVirtual(m_virtualCB->isChecked());
+    m_operation->setInline(m_inlineCB->isChecked());
+    if (m_pOverrideCB)
+        m_operation->setOverride(m_pOverrideCB->isChecked());
     m_docWidget->apply();
 
     return true;
 }
 
-/**
- * Inserts @p type into the type-combobox.
- * The combobox is cleared and all types together with the optional new one
- * sorted and then added again.
- * @param type   a new type to add and selected
- */
-void UMLOperationDialog::insertTypesSorted(const QString& type)
-{
-    QStringList types;
-    // Add "void". We use this for denoting "no return type" independent
-    // of the programming language.
-    // For example, the Ada generator would interpret the return type
-    // "void" as an instruction to generate a procedure instead of a
-    // function.
-    types << QLatin1String("void");
-    // add template parameters
-    UMLClassifier *classifier = dynamic_cast<UMLClassifier*>(m_operation->parent());
-    if (classifier) {
-        UMLClassifierListItemList tmplParams(classifier->getFilteredList(UMLOperation::ot_Template));
-        foreach (UMLClassifierListItem* li, tmplParams) {
-            types << li->name();
-        }
-    }
-    // add the Classes and Interfaces (both are Concepts)
-    UMLClassifierList namesList(m_doc->concepts());
-    foreach (UMLClassifier* obj, namesList) {
-         types << obj->fullyQualifiedName();
-    }
-    // add the given parameter
-    if (!types.contains(type)) {
-        types << type;
-    }
-    types.sort();
 
-    m_pRtypeCB->clear();
-    m_pRtypeCB->insertItems(-1, types);
-
-    // select the given parameter
-    int currentIndex = m_pRtypeCB->findText(type);
-    if (currentIndex > -1) {
-        m_pRtypeCB->setCurrentIndex(currentIndex);
-    }
-}
-
-#include "umloperationdialog.moc"
