@@ -13,6 +13,8 @@
 
 #include <QWidget>
 
+class AssociationWidget;
+class CodeTextEdit;
 class UMLObject;
 class UMLWidget;
 
@@ -25,8 +27,9 @@ class DocumentationWidget : public QWidget
 {
     Q_OBJECT
 public:
-    DocumentationWidget(UMLObject *o, QWidget *parent = 0);
-    DocumentationWidget(UMLWidget *w, QWidget *parent = 0);
+    explicit DocumentationWidget(UMLObject *o, QWidget *parent = 0);
+    explicit DocumentationWidget(UMLWidget *w, QWidget *parent = 0);
+    explicit DocumentationWidget(AssociationWidget *w, QWidget *parent = 0);
     ~DocumentationWidget();
 
     void apply();
@@ -34,8 +37,10 @@ public:
 protected:
     QGroupBox *m_box;
     KTextEdit *m_editField;
+    CodeTextEdit *m_codeEditField;
     UMLObject *m_object;
     UMLWidget *m_widget;
+    AssociationWidget *m_assocWidget;
     void init(const QString &text);
 };
 
