@@ -17,11 +17,15 @@
 #include "umldoc.h"
 #include "umlviewimageexportermodel.h"
 
-#include <klocale.h>
-#include <ktemporaryfile.h>
-#include <kmessagebox.h>
-#include <kstandarddirs.h>
+#if QT_VERSION >= 0x050000
+#include <kjobwidgets.h>
+#endif
+#include <KLocalizedString>
+#include <KMessageBox>
+#if QT_VERSION < 0x050000
 #include <kio/netaccess.h>
+#include <kstandarddirs.h>
+#endif
 #include <kio/job.h>
 
 #include <QApplication>
@@ -58,10 +62,18 @@ DocbookGenerator::~DocbookGenerator()
  */
 bool DocbookGenerator::generateDocbookForProject()
 {
-  KUrl url = umlDoc->url();
+#if QT_VERSION >= 0x050000
+    QUrl url = umlDoc->url();
+#else
+    KUrl url = umlDoc->url();
+#endif
   QString fileName = url.fileName();
   fileName.remove(QRegExp(QLatin1String(".xmi$")));
+#if QT_VERSION >= 0x050000
+  url.setPath(url.path() + QLatin1Char('/') + fileName);
+#else
   url.setFileName(fileName);
+#endif
   uDebug() << "Exporting to directory: " << url;
   generateDocbookForProjectInto(url);
   return true;
@@ -74,12 +86,17 @@ bool DocbookGenerator::generateDocbookForProject()
  * @todo better handling of error conditions
  * @return true if saving is successful and false otherwise.
  */
+#if QT_VERSION >= 0x050000
+void DocbookGenerator::generateDocbookForProjectInto(const QUrl& destDir)
+#else
 void DocbookGenerator::generateDocbookForProjectInto(const KUrl& destDir)
+#endif
 {
     m_destDir = destDir;
     umlDoc->writeToStatusBar(i18n("Exporting all views..."));
 
-    QStringList errors = UMLViewImageExporterModel().exportAllViews(
+    UMLViewList views = UMLApp::app()->document()->viewIterator();
+    QStringList errors = UMLViewImageExporterModel().exportViews(views,
         UMLViewImageExporterModel::mimeTypeToImageType(QLatin1String("image/png")), destDir, false);
     if (!errors.empty()) {
         KMessageBox::errorList(UMLApp::app(), i18n("Some errors happened when exporting the images:"), errors);
@@ -98,14 +115,28 @@ void DocbookGenerator::generateDocbookForProjectInto(const KUrl& destDir)
 void DocbookGenerator::slotDocbookGenerationFinished(const QString& tmpFileName)
 {
     uDebug() << "Generation Finished" << tmpFileName;
+#if QT_VERSION >= 0x050000
+    QUrl url = umlDoc->url();
+#else
     KUrl url = umlDoc->url();
+#endif
     QString fileName = url.fileName();
     fileName.replace(QRegExp(QLatin1String(".xmi$")), QLatin1String(".docbook"));
+#if QT_VERSION >= 0x050000
+    url.setPath(m_destDir.path() + QLatin1Char('/') + fileName);
+#else
     url.setPath(m_destDir.path());
     url.addPath(fileName);
-
+#endif
+#if QT_VERSION >= 0x050000
+    KIO::Job* job = KIO::file_copy(QUrl::fromLocalFile(tmpFileName), url, -1, KIO::Overwrite | KIO::HideProgressInfo);
+    KJobWidgets::setWindow(job, (QWidget*)UMLApp::app());
+    job->exec();
+    if (!job->error()) {
+#else
     KIO::Job* job = KIO::file_copy(KUrl::fromPath(tmpFileName), url, -1, KIO::Overwrite | KIO::HideProgressInfo);
     if (KIO::NetAccess::synchronousRun(job, (QWidget*)UMLApp::app())) {
+#endif
         umlDoc->writeToStatusBar(i18n("Docbook Generation Complete..."));
         m_pStatus = true;
     } else {
@@ -128,5 +159,23 @@ void DocbookGenerator::threadFinished()
     docbookGeneratorJob = 0;
 }
 
+/**
+ * return custom xsl file for generating docbook
+ *
+ * @return filename with path
+ */
+QString DocbookGenerator::customXslFile()
+{
+    QString xslBaseName = QLatin1String("xmi2docbook.xsl");
+#if QT_VERSION >= 0x050000
+    QString xsltFile(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("umbrello5/") + xslBaseName));
+#else
+    QString xsltFile(KGlobal::dirs()->findResource("data", QLatin1String("umbrello/") + xslBaseName));
+#endif
+    if (xsltFile.isEmpty())
+        xsltFile = QLatin1String(DOCGENERATORS_DIR) + QLatin1Char('/') + xslBaseName;
+
+    uDebug() << "XSLT file is'" << xsltFile << "'";
+    return xsltFile;
+}
 
-#include "docbookgenerator.moc"
