@@ -180,17 +180,21 @@ void XhtmlGenerator::slotHtmlGenerated(const QString& tmpFileName)
 
     m_umlDoc->writeToStatusBar(i18n("Copying CSS..."));
 
+    QString cssBaseName = QLatin1String("xmi.css");
 #if QT_VERSION >= 0x050000
-    QString cssFileName(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("xmi.css")));
+    QString cssFileName(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("umbrello5/") + cssBaseName));
 #else
-    QString cssFileName(KGlobal::dirs()->findResource("appdata", QLatin1String("xmi.css")));
+    QString cssFileName(KGlobal::dirs()->findResource("data", QLatin1String("umbrello/") + cssBaseName));
 #endif
+    if (cssFileName.isEmpty())
+        cssFileName = QLatin1String(DOCGENERATORS_DIR) + QLatin1Char('/') + cssBaseName;
+
 #if QT_VERSION >= 0x050000
     QUrl cssUrl = m_destDir;
-    cssUrl.setPath(cssUrl.path() + QLatin1Char('/') + QLatin1String("xmi.css"));
+    cssUrl.setPath(cssUrl.path() + QLatin1Char('/') + cssBaseName);
 #else
     KUrl cssUrl = m_destDir;
-    cssUrl.addPath(QLatin1String("xmi.css"));
+    cssUrl.addPath(cssBaseName);
 #endif
 #if QT_VERSION >= 0x050000
     KIO::Job* cssJob = KIO::file_copy(QUrl::fromLocalFile(cssFileName), cssUrl, -1, KIO::Overwrite | KIO::HideProgressInfo);
@@ -226,3 +230,23 @@ void XhtmlGenerator::threadFinished()
     delete m_d2xg;
     m_d2xg = 0;
 }
+
+/**
+ * return custom xsl file for generating html
+ *
+ * @return filename with path
+ */
+QString XhtmlGenerator::customXslFile()
+{
+  QString xslBaseName = QLatin1String("docbook2xhtml.xsl");
+#if QT_VERSION >= 0x050000
+    QString xsltFileName(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QLatin1String("umbrello5/") + xslBaseName));
+#else
+    QString xsltFileName(KGlobal::dirs()->findResource("data", QLatin1String("umbrello/") + xslBaseName));
+#endif
+  if (xsltFileName.isEmpty())
+      xsltFileName = QLatin1String(DOCGENERATORS_DIR) + QLatin1Char('/') + xslBaseName;
+
+  uDebug() << "XSLT file is'" << xsltFileName << "'";
+  return xsltFileName;
+}
