@@ -23,6 +23,7 @@
 
 #include "basictypes.h"
 #include "debug_utils.h"
+#include "optionstate.h"
 
 #include <kiconloader.h>
 
@@ -198,7 +199,7 @@ QString toString(IconType type)
     switch (type) {
     case it_Accept_Signal: return QLatin1String("accept_signal");
     case it_Accept_TimeEvent: return QLatin1String("accept_time_event");
-    case it_Activity: return QLatin1String("usecase");
+    case it_Activity: return QLatin1String("activity");
     case it_Activity_End: return QLatin1String("end_state");
     case it_Activity_Final: return QLatin1String("final_activity");
     case it_Activity_Initial: return QLatin1String("initial_state");
@@ -238,7 +239,7 @@ QString toString(IconType type)
     case it_Color_Fill: return QLatin1String("fill-color");
     case it_Color_Line: return QLatin1String("draw-brush");
     case it_Combined_Fragment: return QLatin1String("combined_fragment");
-    case it_Component: return QLatin1String("component");
+    case it_Component: return Settings::optionState().generalState.uml2 ? QLatin1String("component") : QLatin1String("component1");
     case it_Composition: return QLatin1String("composition");
     case it_Condition_PrePost: return QLatin1String("PrePostCondition");
     case it_Constraint_Check: return QLatin1String("check_constraint");
@@ -275,6 +276,7 @@ QString toString(IconType type)
     case it_Exception: return QLatin1String("exception");
     case it_Export_Files: return QLatin1String("document-export");
     case it_Export_Picture: return QLatin1String("image-x-generic");
+    case it_File_Open: return QLatin1String("document-open");
     case it_Folder: return QLatin1String("folder-new");
     case it_Folder_Cyan: return QLatin1String("folder");
     case it_Folder_Cyan_Open: return QLatin1String("folder-open");
@@ -306,6 +308,8 @@ QString toString(IconType type)
     case it_InitialState: return QLatin1String("initial_state");
     case it_Instance: return QLatin1String("instance");
     case it_Interface: return QLatin1String("interface");
+    case it_Interface_Requirement: return QLatin1String("interface-requirement");
+    case it_Interface_Provider: return QLatin1String("interface-provider");
     case it_Join: return QLatin1String("join");
     case it_Junction: return QLatin1String("junction");
     case it_Literal_New: return QLatin1String("text-x-generic");
