@@ -11,8 +11,9 @@
 #include "stereotypeswindow.h"
 
 // app includes
+#include "dialog_utils.h"
 #include "stereotype.h"
-#include "stereotypesmodel.h"
+#include "models/stereotypesmodel.h"
 #include "uml.h"
 #include "umldoc.h"
 
@@ -25,8 +26,8 @@
 #include <QSortFilterProxyModel>
 #include <QtDebug>
 
-StereotypesWindow::StereotypesWindow(QWidget *parent)
-    : QDockWidget(i18n("&Stereotypes"), parent)
+StereotypesWindow::StereotypesWindow(const QString &title, QWidget *parent)
+  : QDockWidget(title, parent)
 {
     setObjectName(QLatin1String("StereotypesWindow"));
 
@@ -50,12 +51,14 @@ StereotypesWindow::StereotypesWindow(QWidget *parent)
 
 StereotypesWindow::~StereotypesWindow()
 {
+    QAbstractItemModel *proxy = m_stereotypesTree->model();
     delete m_stereotypesTree;
+    delete proxy;
 }
 
 void StereotypesWindow::modified()
 {
-    UMLStereotype *o = static_cast<UMLStereotype*>(QObject::sender());
+    UMLStereotype *o = dynamic_cast<UMLStereotype*>(QObject::sender());
     if (!o)
         return;
     int index = UMLApp::app()->document()->stereotypes().indexOf(o);
@@ -64,9 +67,21 @@ void StereotypesWindow::modified()
 
 void StereotypesWindow::slotStereotypesDoubleClicked(QModelIndex index)
 {
-    QVariant v = UMLApp::app()->document()->stereotypesModel()->data(index, Qt::UserRole);
+    QVariant v = m_stereotypesTree->model()->data(index, Qt::UserRole);
     if (v.canConvert<UMLStereotype*>()) {
         UMLStereotype *s = v.value<UMLStereotype*>();
         s->showPropertiesDialog(this);
     }
 }
+
+void StereotypesWindow::contextMenuEvent(QContextMenuEvent *event)
+{
+    Q_UNUSED(event);
+    QString name;
+    if (!Dialog_Utils::askDefaultNewName(UMLObject::ot_Stereotype, name))
+        return;
+    if (UMLApp::app()->document()->findStereotype(name))
+        return;
+    UMLStereotype *s = new UMLStereotype(name);
+    UMLApp::app()->document()->stereotypesModel()->addStereotype(s);
+}
