@@ -24,6 +24,7 @@
 #include "umlwidget.h"
 
 #include <QPointer>
+#include <QScrollBar>
 
 DEBUG_REGISTER(UMLView)
 
@@ -31,13 +32,14 @@ DEBUG_REGISTER(UMLView)
  * Constructor.
  */
 UMLView::UMLView(UMLFolder *parentFolder)
-  : QGraphicsView(UMLApp::app()->mainViewWidget()),
-    m_nZoom(100)
+  : QGraphicsView(UMLApp::app()->mainViewWidget())
 {
     setAcceptDrops(true);
     setRenderHints(QPainter::Antialiasing | QPainter::SmoothPixmapTransform);
     setDragMode(NoDrag); //:TODO: RubberBandDrag);
     setScene(new UMLScene(parentFolder, this));
+    setResizeAnchor(AnchorUnderMouse);
+    setTransformationAnchor(AnchorUnderMouse);
 }
 
 /**
@@ -59,15 +61,15 @@ UMLScene* UMLView::umlScene() const
 /**
  * Returns the zoom of the diagram.
  */
-int UMLView::zoom() const
+qreal UMLView::zoom() const
 {
-    return m_nZoom;
+    return matrix().m11()*100.0;
 }
 
 /**
  * Sets the zoom of the diagram.
  */
-void UMLView::setZoom(int zoom)
+void UMLView::setZoom(qreal zoom)
 {
     if (zoom < 10) {
         zoom = 10;
@@ -75,32 +77,21 @@ void UMLView::setZoom(int zoom)
         zoom = 500;
     }
 
+    DEBUG(DBG_SRC) << "setZoom" << zoom;
     QMatrix wm;
     wm.scale(zoom / 100.0, zoom / 100.0);
     setMatrix(wm);
 
-    m_nZoom = currentZoom();
     umlScene()->resizeSceneToItems();
 }
 
-/**
- * Return the current zoom factor.
- */
-int UMLView::currentZoom()
-{
-    return (int)(matrix().m11()*100.0);
-}
-
 /**
  * Shows the properties dialog for the view.
  */
 bool UMLView::showPropertiesDialog(QWidget *parent)
 {
-    bool success = false;
     QPointer<UMLViewDialog> dlg = new UMLViewDialog(parent, umlScene());
-    if (dlg->exec() == QDialog::Accepted) {
-        success = true;
-    }
+    bool success = dlg->exec() == QDialog::Accepted;
     delete dlg;
     return success;
 }
@@ -109,14 +100,14 @@ void UMLView::zoomIn()
 {
     QMatrix wm = matrix();
     wm.scale(1.5, 1.5); // adjust zooming step here
-    setZoom((int)(wm.m11()*100.0));
+    setZoom(wm.m11()*100.0);
 }
 
 void UMLView::zoomOut()
 {
     QMatrix wm = matrix();
     wm.scale(2.0 / 3.0, 2.0 / 3.0); //adjust zooming step here
-    setZoom((int)(wm.m11()*100.0));
+    setZoom(wm.m11()*100.0);
 }
 
 /**
@@ -137,20 +128,21 @@ void UMLView::wheelEvent(QWheelEvent* event)
     // get the position of the mouse before scaling, in scene coords
     QPointF pointBeforeScale(mapToScene(event->pos()));
 
-    // get the original screen centerpoint
-    QPointF screenCenter = center();
-
     // scale the view ie. do the zoom
     double scaleFactor = 1.15;
     if (event->delta() > 0) {
         // zoom in
-        if (currentZoom() < 500) {
-            scale(scaleFactor, scaleFactor);
+        if (zoom() < 500) {
+            setZoom(zoom() * scaleFactor);
+        } else {
+            return;
         }
     } else {
         // zooming out
-        if (currentZoom() > 10) {
-            scale(1.0 / scaleFactor, 1.0 / scaleFactor);
+        if (zoom() > 10) {
+            setZoom(zoom() / scaleFactor);
+        } else {
+            return;
         }
     }
 
@@ -161,25 +153,11 @@ void UMLView::wheelEvent(QWheelEvent* event)
     QPointF offset = pointBeforeScale - pointAfterScale;
 
     // adjust to the new center for correct zooming
-    QPointF newCenter = screenCenter + offset;
-    setCenter(newCenter);
+    QPointF newCenter = mapToScene(viewport()->rect().center()) + offset;
 
-    DEBUG(DBG_SRC) << "currentZoom=" << currentZoom();
-    UMLApp::app()->slotZoomSliderMoved(currentZoom());
-}
+   centerOn(newCenter);
 
-/**
- * Need to update the center so there is no jolt in the
- * interaction after resizing the widget.
- */
-void UMLView::resizeEvent(QResizeEvent* event)
-{
-    // get the rectangle of the visible area in scene coords
-    QRectF visibleArea = mapToScene(rect()).boundingRect();
-    setCenter(visibleArea.center());
-
-    // call the subclass resize so the scrollbars are updated correctly
-    QGraphicsView::resizeEvent(event);
+    UMLApp::app()->setZoom(zoom(), false);
 }
 
 /**
@@ -211,14 +189,6 @@ void UMLView::hideEvent(QHideEvent* he)
     us->hideEvent(he);
 }
 
-/**
- * Override standard method.
- */
-void UMLView::closeEvent(QCloseEvent* ce)
-{
-    QWidget::closeEvent(ce);
-}
-
 /**
  * Override standard method.
  */
@@ -248,65 +218,13 @@ void UMLView::mouseReleaseEvent(QMouseEvent* event)
 }
 
 /**
- * Sets the current centerpoint.  Also updates the scene's center point.
- * Unlike centerOn, which has no way of getting the floating point center
- * back, setCenter() stores the center point.  It also handles the special
- * sidebar case.  This function will claim the centerPoint to sceneRec ie.
- * the centerPoint must be within the sceneRec.
+ * Override standard method.
  */
-void UMLView::setCenter(const QPointF& centerPoint)
+void UMLView::resizeEvent(QResizeEvent *event)
 {
-    // get the rectangle of the visible area in scene coords
-    QRectF visibleArea = mapToScene(rect()).boundingRect();
-
-    // get the scene area
-    QRectF sceneBounds = sceneRect();
-
-    double boundX = visibleArea.width() / 2.0;
-    double boundY = visibleArea.height() / 2.0;
-    double boundWidth = sceneBounds.width() - 2.0 * boundX;
-    double boundHeight = sceneBounds.height() - 2.0 * boundY;
-
-    // the max boundary that the centerPoint can be to
-    QRectF bounds(boundX, boundY, boundWidth, boundHeight);
-
-    if (bounds.contains(centerPoint)) {
-        // we are within the bounds
-        m_currentCenterPoint = centerPoint;
-    } else {
-        // we need to clamp or use the center of the screen
-        if(visibleArea.contains(sceneBounds)) {
-            // use the center of scene ie. we can see the whole scene
-            m_currentCenterPoint = sceneBounds.center();
-        } else {
-
-            m_currentCenterPoint = centerPoint;
-
-            // we need to clamp the center. The centerPoint is too large
-            if (centerPoint.x() > bounds.x() + bounds.width()) {
-                m_currentCenterPoint.setX(bounds.x() + bounds.width());
-            } else if (centerPoint.x() < bounds.x()) {
-                m_currentCenterPoint.setX(bounds.x());
-            }
-
-            if (centerPoint.y() > bounds.y() + bounds.height()) {
-                m_currentCenterPoint.setY(bounds.y() + bounds.height());
-            } else if (centerPoint.y() < bounds.y()) {
-                m_currentCenterPoint.setY(bounds.y());
-            }
-
-        }
-    }
-    // update the scrollbars
-    centerOn(m_currentCenterPoint);
+    bool oldState1 = verticalScrollBar()->blockSignals(true);
+    bool oldState2 = horizontalScrollBar()->blockSignals(true);
+    QGraphicsView::resizeEvent(event);
+    verticalScrollBar()->blockSignals(oldState1);
+    horizontalScrollBar()->blockSignals(oldState2);
 }
-
-/**
- * Get the center.
- */
-QPointF UMLView::center()
-{
-    return m_currentCenterPoint;
-}
-
-#include "umlview.moc"
