@@ -35,13 +35,10 @@ public:
 
     virtual void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget = 0);
 
-    void saveToXMI(QDomDocument& qDoc, QDomElement& qElement);
+    void saveToXMI1(QDomDocument& qDoc, QDomElement& qElement);
 
 protected:
     QSizeF minimumSize() const;
-
-private:
-    ListPopupMenu* m_pMenu;  ///< the right mouse button menu
 };
 
 #endif
