@@ -20,7 +20,6 @@
 #include "umlscene.h"
 #include "umlview.h"
 #include "floatingtextwidget.h"
-#include "debug_utils.h"
 #include "umlwidgets/childwidgetplacementpin.h"
 #include "umlwidgets/childwidgetplacementport.h"
 
@@ -81,7 +80,7 @@ void PinPortBase::init(UMLWidget *owner)
     setMaximumSize(fixedSize);
     setSize(fixedSize);
 
-    m_childPlacement->setInitialPosition();
+    //m_childPlacement->setInitialPosition();
 }
 
 UMLWidget* PinPortBase::ownerWidget() const
@@ -89,6 +88,11 @@ UMLWidget* PinPortBase::ownerWidget() const
     return dynamic_cast<UMLWidget*>(parentItem());
 }
 
+void PinPortBase::setInitialPosition(const QPointF &scenePos)
+{
+    m_childPlacement->setInitialPosition(scenePos);
+}
+
 /**
  * Overrides method from UMLWidget in order to set a tooltip.
  * The tooltip is set to the name().
