@@ -31,6 +31,8 @@
 #include <QEvent>
 #include <QPolygon>
 
+DEBUG_REGISTER_DISABLED(SignalWidget)
+
 /**
  * Creates a Signal widget.
  *
@@ -228,8 +230,9 @@ void SignalWidget::setSignalType(SignalType signalType)
 /**
  * Show a properties dialog for a UMLWidget.
  */
-void SignalWidget::showPropertiesDialog()
+bool SignalWidget::showPropertiesDialog()
 {
+    return false;
 }
 
 /**
