@@ -362,7 +362,7 @@ void WorkToolBar::loadPixmaps()
         { tbb_Artifact,                 i18n("Artifact"),                Icon_Utils::it_Artifact,                SLOT(slotArtifact()) },
         { tbb_Interface,                i18n("Interface"),               Icon_Utils::it_Interface,               SLOT(slotInterface()) },
         { tbb_Interface_Provider,       i18n("Interface Provider"),      Icon_Utils::it_Interface_Provider,      SLOT(slotInterfaceProvider()) },
-        { tbb_Interface_Requirement,    i18n("Interface required"),      Icon_Utils::it_Interface_Requirement,   SLOT(slotInterfaceRequirement()) },
+        { tbb_Interface_Requirement,    i18n("Interface required"),      Icon_Utils::it_Interface_Requirement,   SLOT(slotInterfaceRequired()) },
         { tbb_Datatype,                 i18n("Datatype"),                Icon_Utils::it_Datatype,                SLOT(slotDatatype()) },
         { tbb_Enum,                     i18n("Enum"),                    Icon_Utils::it_Enum,                    SLOT(slotEnum()) },
         { tbb_Entity,                   i18n("Entity"),                  Icon_Utils::it_Entity,                  SLOT(slotEntity()) },
