@@ -86,6 +86,8 @@ public:
         tbb_UseCase,
         tbb_Class,
         tbb_Interface,
+        tbb_Interface_Provider,
+        tbb_Interface_Requirement,
         tbb_Datatype,
         tbb_Enum,
         tbb_Entity,
@@ -103,6 +105,7 @@ public:
         tbb_End_Activity,
         tbb_Final_Activity,
         tbb_Pin,
+        tbb_Port,
         tbb_Branch,
         tbb_Fork,
         tbb_DeepHistory,
@@ -117,14 +120,20 @@ public:
         tbb_PrePostCondition,
         tbb_Category,
         tbb_Category2Parent,
-        tbb_Child2Category
+        tbb_Child2Category,
+        tbb_Instance,
+        tbb_SubSystem
     };
 
 private:
 
     typedef QMap<Uml::DiagramType::Enum, ToolBar_Buttons> OldToolMap;
     typedef QMap<ToolBar_Buttons, QCursor> CursorMap;
+#if QT_VERSION >= 0x050000
+    typedef QMap<ToolBar_Buttons, QAction*> ActionsMap;
+#else
     typedef QMap<ToolBar_Buttons, KAction*> ActionsMap;
+#endif
 
     ToolBar_Buttons          m_CurrentButtonID;
     OldToolMap               m_map;
@@ -180,6 +189,8 @@ public slots:
     void slotUseCase();
     void slotClass();
     void slotInterface();
+    void slotInterfaceProvider();
+    void slotInterfaceRequired();
     void slotDatatype();
     void slotEnum();
     void slotEntity();
@@ -211,10 +222,13 @@ public slots:
     void slotException();
     void slotPrePostCondition();
     void slotPin();
+    void slotPort();
     void slotObject_Node();
     void slotCategory();
     void slotCategory2Parent();
     void slotChild2Category();
+    void slotInstance();
+    void slotSubsystem();
 };
 
 #endif
